package com.masterdaweb.androidchart;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.widget.Toast;

import com.github.mikephil.charting.charts.LineChart;
import com.github.mikephil.charting.components.AxisBase;
import com.github.mikephil.charting.components.Description;
import com.github.mikephil.charting.components.XAxis;
import com.github.mikephil.charting.components.YAxis;
import com.github.mikephil.charting.data.Entry;
import com.github.mikephil.charting.data.LineData;
import com.github.mikephil.charting.data.LineDataSet;
import com.github.mikephil.charting.formatter.IAxisValueFormatter;
import com.github.mikephil.charting.highlight.Highlight;
import com.github.mikephil.charting.listener.OnChartValueSelectedListener;

import java.util.ArrayList;
import java.util.List;

public class MainActivity extends Activity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        LineChart chart = (LineChart) findViewById(R.id.chart);
        //
        List<Entry> entries = new ArrayList<Entry>();
        entries.add(new Entry(1, 10f));
        entries.add(new Entry(2, 75f));
        entries.add(new Entry(3, 50f));
        entries.add(new Entry(3, 100f));
        entries.add(new Entry(4, 200f));

        XAxis xAxis = chart.getXAxis();
        xAxis.setValueFormatter(new MyXAxisValueFormatter());
        // Evita a duplicação dos meses na linha X
        xAxis.setGranularity(1f);

        YAxis yAxis = chart.getAxisLeft();
        yAxis.setValueFormatter(new MyYAxisValueFormatter());

        LineDataSet dataSet = new LineDataSet(entries, "Vendas");
        dataSet.setDrawFilled(true);
        dataSet.setDrawValues(false);
        LineData lineData = new LineData(dataSet);
        chart.setData(lineData);
        // Desativa o ZOOM do Touch
        chart.setDoubleTapToZoomEnabled(false);
        // Listener para exibir Toast ao tocar no gráfico
        chart.setOnChartValueSelectedListener(new OnChartValueSelectedListener() {
            @Override
            public void onValueSelected(Entry e, Highlight h) {
                Toast.makeText(MainActivity.this, "R$ " + e.getY(),
                        Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onNothingSelected() {

            }
        });
        // Efeito de animação
        chart.animateXY(3000, 3000);
        chart.invalidate();
    }

    // Formata os valores na linha X
    public class MyXAxisValueFormatter implements IAxisValueFormatter {

        private String[] mValues = {"Janeiro", "Fevereiro", "Março", "Abril", "Maio"};

        @Override
        public String getFormattedValue(float value, AxisBase axis) {
            Log.d("Teste", mValues[(int) value]);
            return mValues[(int) value];
        }
    }

    // Formata os valores na linha Y
    public class MyYAxisValueFormatter implements IAxisValueFormatter {

        @Override
        public String getFormattedValue(float value, AxisBase axis) {
            return "R$ " + value;
        }
    }
}
